Introduction
============

This add-on does nothing but enabling the Archetype based contenttype 'Topic',
a.k.a old-style-collections, and their configuration-UI in the controlpanel,
disabled by default since of Plone 4.1
